@@ -228,10 +228,11 @@ impl_Bonobo_Control_activate (PortableServer_Servant servant,
 	 * if our active state is not what we are changing it to, then
 	 * don't emit the signal
 	 */
-	if (control->priv->active != activated)
+	if (control->priv->active == old_activated)
 		return;
 
-	g_signal_emit (control, control_signals [ACTIVATE], 0, (gboolean) activated);
+	g_signal_emit (control, control_signals [ACTIVATE], 0, control->priv->active);
+	bonobo_control_activate_notify (control, control->priv->active, ev);
 }
 
 static void
