@@ -17,11 +17,11 @@
 G_BEGIN_DECLS
 
 #define BONOBO_TYPE_DOCK_ITEM_GRIP            (bonobo_dock_item_grip_get_type())
-#define BONOBO_DOCK_ITEM_GRIP(obj)            (GTK_CHECK_CAST ((obj), BONOBO_TYPE_DOCK_ITEM_GRIP, BonoboDockItemGrip))
-#define BONOBO_DOCK_ITEM_GRIP_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), BONOBO_TYPE_DOCK_ITEM_GRIP, BonoboDockItemGripClass))
-#define BONOBO_IS_DOCK_ITEM_GRIP(obj)         (GTK_CHECK_TYPE ((obj), BONOBO_TYPE_DOCK_ITEM_GRIP))
-#define BONOBO_IS_DOCK_ITEM_GRIP_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), BONOBO_TYPE_DOCK_ITEM_GRIP))
-#define BONOBO_DOCK_ITEM_GRIP_GET_CLASS(obj)  (GTK_CHECK_GET_CLASS ((obj), BONOBO_TYPE_DOCK_ITEM_GRIP, BonoboDockItemGripClass))
+#define BONOBO_DOCK_ITEM_GRIP(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), BONOBO_TYPE_DOCK_ITEM_GRIP, BonoboDockItemGrip))
+#define BONOBO_DOCK_ITEM_GRIP_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), BONOBO_TYPE_DOCK_ITEM_GRIP, BonoboDockItemGripClass))
+#define BONOBO_IS_DOCK_ITEM_GRIP(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BONOBO_TYPE_DOCK_ITEM_GRIP))
+#define BONOBO_IS_DOCK_ITEM_GRIP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BONOBO_TYPE_DOCK_ITEM_GRIP))
+#define BONOBO_DOCK_ITEM_GRIP_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), BONOBO_TYPE_DOCK_ITEM_GRIP, BonoboDockItemGripClass))
 
 typedef struct {
 	GtkWidget parent;
